@@ -1,4 +1,4 @@
-# Copyrights 2007-2016 by [Mark Overmeer].
+# Copyrights 2007-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -8,7 +8,7 @@ use strict;
 
 package Log::Report;
 use vars '$VERSION';
-$VERSION = '1.17';
+$VERSION = '1.19';
 
 use base 'Exporter';
 
@@ -171,7 +171,9 @@ sub dispatcher($@)
         if(!$reopen_disp)
         {   my $has = first {$_->name eq $name} @$disps;
             if(defined $has && $has ne $default_dispatcher)
-            {   trace "not reopening $name";
+            {   my $default = $name eq 'default'
+                   ? ' (refreshing configuration instead)' : '';
+                trace "not reopening $name$default";
                 return $has;
             }
         }
@@ -292,7 +294,8 @@ sub try(&@)
 
     my $is_exception = blessed $err && $err->isa('Log::Report::Exception');
     if($err && !$is_exception && !$disp->wasFatal)
-    {   ($err, my($opts, $reason, $text)) = Log::Report::Die::die_decode($err);
+    {   ($err, my($opts, $reason, $text))
+           = Log::Report::Die::die_decode($err, on_die => $disp->die2reason);
         $disp->log($opts, $reason, __$text);
     }
 
