@@ -1,4 +1,4 @@
-# Copyrights 2007-2016 by [Mark Overmeer].
+# Copyrights 2007-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Dispatcher::Syslog;
 use vars '$VERSION';
-$VERSION = '1.17';
+$VERSION = '1.19';
 
 use base 'Log::Report::Dispatcher';
 
@@ -104,7 +104,7 @@ sub log($$$$$)
 
     # handle each line in message separately
     $text    =~ s/\s+$//s;
-    my @text = split /\n/, $format->($text, $domain, $msg);
+    my @text = split /\n/, $format->($text, $domain, $msg, %$opts);
 
     my $prio    = $self->reasonToPrio($reason);
     my $charset = $self->{LRDS_charset};
