@@ -1,4 +1,4 @@
-# Copyrights 2007-2016 by [Mark Overmeer].
+# Copyrights 2007-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Dispatcher::Try;
 use vars '$VERSION';
-$VERSION = '1.17';
+$VERSION = '1.19';
 
 use base 'Log::Report::Dispatcher';
 
@@ -29,6 +29,7 @@ sub init($)
     $self->{exceptions} = delete $args->{exceptions} || [];
     $self->{died}       = delete $args->{died};
     $self->hide($args->{hide} // 'NONE');
+    $self->{on_die}     = $args->{on_die} // 'ERROR';
     $self;
 }
 
@@ -67,6 +68,9 @@ sub hide(@)
       :    +{ map +($_ => 1), @h };
 }
 
+
+sub die2reason() { shift->{on_die} }
+
 #-----------------
 
 sub log($$$$)
